"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadConfig = void 0;
const yaml_1 = __importDefault(require("yaml"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const load_json_file_1 = __importDefault(require("load-json-file"));
const koishi_1 = require("koishi");
const logger = new koishi_1.Logger('bootstrap-config-loader');
async function loadFromYaml() {
    return yaml_1.default.parse(await fs_1.default.promises.readFile('./koishi.config.yml', 'utf-8'));
}
function loadFromJs() {
    return require(path_1.default.join(process.cwd(), 'koishi.config.js'));
}
async function loadFromJson() {
    return await (0, load_json_file_1.default)('./koishi.config.json');
}
async function loadConfig() {
    try {
        logger.info(`Reading config from ./koishi.config.yml.`);
        return await loadFromYaml();
    }
    catch (e) {
        logger.warn(`Failed reading from YAML: ${e.toString()} , trying JS.`);
        logger.info(`Reading config from ./koishi.config.js.`);
        try {
            return loadFromJs();
        }
        catch (e) {
            logger.warn(`Failed reading from JS: ${e.toString()} , trying JSON.`);
            logger.info(`Reading config from ./koishi.config.json.`);
            try {
                return await loadFromJson();
            }
            catch (e) {
                logger.warn(`Failed reading from JSON: ${e.toString()} , exiting.`);
                return;
            }
        }
    }
}
exports.loadConfig = loadConfig;
//# sourceMappingURL=load-config.js.map